@@ -1,4 +1,4 @@
-﻿define(['components/paperdialoghelper', 'paper-dialog', 'paper-fab'], function (paperDialogHelper) {
+﻿define(['paperdialoghelper', 'paper-dialog', 'paper-fab'], function (paperDialogHelper) {
 
     var currentItemId;
     var currentFile;
@@ -134,12 +134,18 @@
             currentItemId = itemId;
 
             var dlg = paperDialogHelper.createDialog({
-                theme: options.theme
+                size: 'fullscreen-border'
             });
 
+            var theme = options.theme || 'b';
+
+            dlg.classList.add('ui-body-' + theme);
+            dlg.classList.add('background-theme-' + theme);
+            dlg.classList.add('popupEditor');
+
             var html = '';
             html += '<h2 class="dialogHeader">';
-            html += '<paper-fab icon="arrow-back" mini class="btnCloseDialog"></paper-fab>';
+            html += '<paper-fab icon="arrow-back" mini class="btnCloseDialog" tabindex="-1"></paper-fab>';
             html += '<div style="display:inline-block;margin-left:.6em;vertical-align:middle;">' + Globalize.translate('HeaderUploadImage') + '</div>';
             html += '</h2>';
 
@@ -158,6 +164,8 @@
             var editorContent = dlg.querySelector('.editorContent');
             initEditor(editorContent);
 
+            $('#selectImageType', dlg).val(options.imageType || 'Primary');
+
             $('.btnCloseDialog', dlg).on('click', function () {
 
                 paperDialogHelper.close(dlg);
