@@ -1,9 +1,384 @@
-﻿define(['components/paperdialoghelper', 'paper-checkbox', 'paper-dialog', 'paper-input'], function (paperDialogHelper) {
+﻿define(['paperdialoghelper', 'paper-checkbox', 'paper-dialog', 'paper-input', 'paper-item-body', 'paper-icon-item', 'paper-textarea', 'paper-fab'], function (paperDialogHelper) {
 
-    var currentDialog;
+    var currentContext;
     var metadataEditorInfo;
     var currentItem;
 
+    function closeDialog(isSubmitted) {
+
+        if (currentContext.tagName == 'PAPER-DIALOG') {
+            paperDialogHelper.close(currentContext);
+        }
+    }
+
+    function submitUpdatedItem(form, item) {
+
+        function afterContentTypeUpdated() {
+
+            Dashboard.alert(Globalize.translate('MessageItemSaved'));
+
+            Dashboard.hideLoadingMsg();
+            closeDialog(true);
+        }
+
+        ApiClient.updateItem(item).then(function () {
+
+            var newContentType = $('#selectContentType', form).val() || '';
+
+            if ((metadataEditorInfo.ContentType || '') != newContentType) {
+
+                ApiClient.ajax({
+
+                    url: ApiClient.getUrl('Items/' + item.Id + '/ContentType', {
+                        ContentType: newContentType
+                    }),
+
+                    type: 'POST'
+
+                }).then(function () {
+                    afterContentTypeUpdated();
+                });
+
+            } else {
+                afterContentTypeUpdated();
+            }
+
+        });
+    }
+
+    function getSelectedAirDays(form) {
+        return $('.chkAirDay:checked', form).map(function () {
+            return this.getAttribute('data-day');
+        }).get();
+    }
+
+    function getAlbumArtists(form) {
+
+        return $('#txtAlbumArtist', form).val().trim().split(';').filter(function (s) {
+
+            return s.length > 0;
+
+        }).map(function (a) {
+
+            return {
+                Name: a
+            };
+        });
+    }
+
+    function getArtists(form) {
+
+        return $('#txtArtist', form).val().trim().split(';').filter(function (s) {
+
+            return s.length > 0;
+
+        }).map(function (a) {
+
+            return {
+                Name: a
+            };
+        });
+    }
+
+    function getDateFromForm(form, element, property) {
+
+        var val = $(element, form).val();
+
+        if (!val) {
+            return null;
+        }
+
+        if (currentItem[property]) {
+
+            var date = parseISO8601Date(currentItem[property], { toLocal: true });
+
+            var parts = date.toISOString().split('T');
+
+            // If the date is the same, preserve the time
+            if (parts[0].indexOf(val) == 0) {
+
+                var iso = parts[1];
+
+                val += 'T' + iso;
+            }
+        }
+
+        return val;
+    }
+
+    function onSubmit() {
+
+        Dashboard.showLoadingMsg();
+
+        var form = this;
+
+        try {
+            var item = {
+                Id: currentItem.Id,
+                Name: $('#txtName', form).val(),
+                ForcedSortName: $('#txtSortName', form).val(),
+                DisplayMediaType: $('#txtDisplayMediaType', form).val(),
+                CommunityRating: $('#txtCommunityRating', form).val(),
+                VoteCount: $('#txtCommunityVoteCount', form).val(),
+                HomePageUrl: $('#txtHomePageUrl', form).val(),
+                Budget: $('#txtBudget', form).val(),
+                Revenue: $('#txtRevenue', form).val(),
+                CriticRating: $('#txtCriticRating', form).val(),
+                CriticRatingSummary: $('#txtCriticRatingSummary', form).val(),
+                IndexNumber: $('#txtIndexNumber', form).val() || null,
+                DisplaySpecialsWithSeasons: form.querySelector('#chkDisplaySpecialsInline').checked,
+                AbsoluteEpisodeNumber: $('#txtAbsoluteEpisodeNumber', form).val(),
+                DvdEpisodeNumber: $('#txtDvdEpisodeNumber', form).val(),
+                DvdSeasonNumber: $('#txtDvdSeasonNumber', form).val(),
+                AirsBeforeSeasonNumber: $('#txtAirsBeforeSeason', form).val(),
+                AirsAfterSeasonNumber: $('#txtAirsAfterSeason', form).val(),
+                AirsBeforeEpisodeNumber: $('#txtAirsBeforeEpisode', form).val(),
+                ParentIndexNumber: $('#txtParentIndexNumber', form).val() || null,
+                DisplayOrder: $('#selectDisplayOrder', form).val(),
+                Players: $('#txtPlayers', form).val(),
+                Album: $('#txtAlbum', form).val(),
+                AlbumArtist: getAlbumArtists(form),
+                ArtistItems: getArtists(form),
+                Metascore: $('#txtMetascore', form).val(),
+                AwardSummary: $('#txtAwardSummary', form).val(),
+                Overview: $('#txtOverview', form).val(),
+                ShortOverview: $('#txtShortOverview', form).val(),
+                Status: $('#selectStatus', form).val(),
+                AirDays: getSelectedAirDays(form),
+                AirTime: $('#txtAirTime', form).val(),
+                Genres: editableListViewValues($("#listGenres", form)),
+                ProductionLocations: editableListViewValues($("#listCountries", form)),
+                Tags: editableListViewValues($("#listTags", form)),
+                Keywords: editableListViewValues($("#listKeywords", form)),
+                Studios: editableListViewValues($("#listStudios", form)).map(function (element) { return { Name: element }; }),
+
+                PremiereDate: getDateFromForm(form, '#txtPremiereDate', 'PremiereDate'),
+                DateCreated: getDateFromForm(form, '#txtDateAdded', 'DateCreated'),
+                EndDate: getDateFromForm(form, '#txtEndDate', 'EndDate'),
+                ProductionYear: $('#txtProductionYear', form).val(),
+                AspectRatio: $('#txtOriginalAspectRatio', form).val(),
+                Video3DFormat: $('#select3dFormat', form).val(),
+
+                OfficialRating: $('#selectOfficialRating', form).val(),
+                CustomRating: $('#selectCustomRating', form).val(),
+                People: currentItem.People,
+                LockData: form.querySelector("#chkLockData").checked,
+                LockedFields: $('.selectLockedField', form).get().filter(function (c) {
+                    return !c.checked;
+                }).map(function (c) {
+                    return c.getAttribute('data-value');
+                })
+            };
+
+            item.ProviderIds = $.extend({}, currentItem.ProviderIds || {});
+
+            $('.txtExternalId', form).each(function () {
+
+                var providerkey = this.getAttribute('data-providerkey');
+
+                item.ProviderIds[providerkey] = this.value;
+            });
+
+            item.PreferredMetadataLanguage = $('#selectLanguage', form).val();
+            item.PreferredMetadataCountryCode = $('#selectCountry', form).val();
+
+            if (currentItem.Type == "Person") {
+
+                var placeOfBirth = $('#txtPlaceOfBirth', form).val();
+
+                item.ProductionLocations = placeOfBirth ? [placeOfBirth] : [];
+            }
+
+            if (currentItem.Type == "Series") {
+
+                // 600000000
+                var seriesRuntime = $('#txtSeriesRuntime', form).val();
+                item.RunTimeTicks = seriesRuntime ? (seriesRuntime * 600000000) : null;
+            }
+
+            var tagline = $('#txtTagline', form).val();
+            item.Taglines = tagline ? [tagline] : [];
+
+            submitUpdatedItem(form, item);
+        } catch (err) {
+            alert(err);
+        }
+
+        // Disable default form submission
+        return false;
+    }
+
+    function parentWithClass(elem, className) {
+
+        while (!elem.classList || !elem.classList.contains(className)) {
+            elem = elem.parentNode;
+
+            if (!elem) {
+                return null;
+            }
+        }
+
+        return elem;
+    }
+
+    function editableListViewValues(list) {
+        return list.find('.textValue').map(function () { return $(this).text(); }).get();
+    }
+
+    function addElementToEditableListview(source, sortCallback) {
+
+        require(['prompt'], function (prompt) {
+
+            prompt({
+                label: 'Value:'
+            }).then(function (text) {
+                var list = $(source).parents('.editableListviewContainer').find('.paperList');
+                var items = editableListViewValues(list);
+                items.push(text);
+                populateListView(list[0], items, sortCallback);
+            });
+        });
+    }
+
+    function removeElementFromListview(source) {
+        $(source).parents('paper-icon-item').remove();
+    }
+
+    function editPerson(context, person, index) {
+
+        require(['components/metadataeditor/personeditor'], function (personeditor) {
+
+            personeditor.show(person).then(function (updatedPerson) {
+
+                var isNew = index == -1;
+
+                if (isNew) {
+                    currentItem.People.push(updatedPerson);
+                }
+
+                populatePeople(context, currentItem.People);
+            });
+        });
+    }
+
+    function showRefreshMenu(context, button) {
+
+        var items = [];
+
+        items.push({
+            name: Globalize.translate('ButtonLocalRefresh'),
+            id: 'local',
+            ironIcon: 'refresh'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonAddMissingData'),
+            id: 'missing',
+            ironIcon: 'refresh'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonFullRefresh'),
+            id: 'full',
+            ironIcon: 'refresh'
+        });
+
+        require(['actionsheet'], function (actionsheet) {
+
+            actionsheet.show({
+                items: items,
+                positionTo: button,
+                callback: function (id) {
+
+                    if (id) {
+                    
+                        Dashboard.showLoadingMsg();
+                        // For now this is a hack
+                        setTimeout(function () {
+                            Dashboard.hideLoadingMsg();
+                        }, 5000);
+                    }
+
+                    switch (id) {
+
+                        case 'local':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'None',
+                                MetadataRefreshMode: 'ValidationOnly',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: false
+                            });
+                            break;
+                        case 'missing':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'FullRefresh',
+                                MetadataRefreshMode: 'FullRefresh',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: false
+                            });
+                            break;
+                        case 'full':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'FullRefresh',
+                                MetadataRefreshMode: 'FullRefresh',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: true
+                            });
+                            break;
+                        default:
+                            break;
+                    }
+                }
+            });
+
+        });
+
+    }
+
+    function showMoreMenu(context, button) {
+
+        var items = [];
+
+        items.push({
+            name: Globalize.translate('ButtonIdentify'),
+            id: 'identify',
+            ironIcon: 'info'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonRefresh'),
+            id: 'refresh',
+            ironIcon: 'refresh'
+        });
+
+        require(['actionsheet'], function (actionsheet) {
+
+            actionsheet.show({
+                items: items,
+                positionTo: button,
+                callback: function (id) {
+
+                    switch (id) {
+
+                        case 'identify':
+                            LibraryBrowser.identifyItem(currentItem.Id);
+                            break;
+                        case 'refresh':
+                            showRefreshMenu(context, button);
+                            break;
+                        default:
+                            break;
+                    }
+                }
+            });
+
+        });
+
+    }
+
     function onWebSocketMessageReceived(e, data) {
 
         var msg = data;
@@ -13,36 +388,21 @@
             if (msg.Data.ItemsUpdated.indexOf(currentItem.Id) != -1) {
 
                 console.log('Item updated - reloading metadata');
-                reload(currentDialog, currentItem.Id);
+                reload(currentContext, currentItem.Id);
             }
         }
     }
 
-    function bindItemChanged() {
+    function bindItemChanged(context) {
 
         Events.on(ApiClient, "websocketmessage", onWebSocketMessageReceived);
     }
 
-    function unbindItemChanged() {
+    function unbindItemChanged(context) {
 
         Events.off(ApiClient, "websocketmessage", onWebSocketMessageReceived);
     }
 
-    function closeDialog(isSubmitted) {
-
-        paperDialogHelper.close(currentDialog);
-    }
-
-    function onSubmit() {
-
-        Dashboard.showLoadingMsg();
-
-        var form = this;
-
-        // Disable default form submission
-        return false;
-    }
-
     function init(context) {
 
         $('.btnCancel', context).on('click', function () {
@@ -50,7 +410,50 @@
             closeDialog(false);
         });
 
+        context.querySelector('.btnMore').addEventListener('click', function (e) {
+
+            showMoreMenu(context, e.target);
+        });
+
+        context.querySelector('.btnHeaderSave').addEventListener('click', function (e) {
+
+            context.querySelector('.btnSave').click();
+        });
+
+        context.querySelector('#chkLockData').addEventListener('click', function (e) {
+
+            if (!e.target.checked) {
+                $('.providerSettingsContainer').show();
+            } else {
+                $('.providerSettingsContainer').hide();
+            }
+        });
+
+        context.addEventListener('click', function (e) {
+
+            var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
+            if (btnRemoveFromEditorList) {
+                removeElementFromListview(btnRemoveFromEditorList);
+            }
+
+            var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
+            if (btnAddTextItem) {
+                addElementToEditableListview(btnAddTextItem);
+            }
+
+        });
+
         $('form', context).off('submit', onSubmit).on('submit', onSubmit);
+
+        $("#btnAddPerson", context).on('click', function (event, data) {
+
+            editPerson(context, {}, -1);
+        });
+
+        // For now this is only supported in dialog mode because we have a way of knowing when it closes
+        if (currentContext.tagName == 'PAPER-DIALOG') {
+            bindItemChanged(context);
+        }
     }
 
     function getItem(itemId) {
@@ -66,10 +469,7 @@
             return ApiClient.getJSON(ApiClient.getUrl('Items/' + itemId + '/MetadataEditor'));
         }
 
-        return new Promise(function (resolve, reject) {
-
-            resolve({});
-        });
+        return Promise.resolve({});
     }
 
     function populateCountries(select, allCountries) {
@@ -339,13 +739,13 @@
 
         if (item.Type == "Person") {
             context.querySelector('#txtProductionYear').label = Globalize.translate('LabelBirthYear');
-            context.querySelector("label[for='txtPremiereDate']").innerHTML = Globalize.translate('LabelBirthDate');
-            context.querySelector("label[for='txtEndDate']").innerHTML = Globalize.translate('LabelDeathDate');
+            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelBirthDate');
+            context.querySelector("#txtEndDate").label = Globalize.translate('LabelDeathDate');
             $('#fldPlaceOfBirth', context).show();
         } else {
             context.querySelector('#txtProductionYear').label = Globalize.translate('LabelYear');
-            context.querySelector("label[for='txtPremiereDate']").innerHTML = Globalize.translate('LabelReleaseDate');
-            context.querySelector("label[for='txtEndDate']").innerHTML = Globalize.translate('LabelEndDate');
+            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelReleaseDate');
+            context.querySelector("#txtEndDate").label = Globalize.translate('LabelEndDate');
             $('#fldPlaceOfBirth', context).hide();
         }
 
@@ -439,22 +839,22 @@
 
         });
 
-        populateListView($('#listCountries', context), item.ProductionLocations || []);
-        populateListView($('#listGenres', context), item.Genres);
+        populateListView($('#listCountries', context)[0], item.ProductionLocations || []);
+        populateListView($('#listGenres', context)[0], item.Genres);
         populatePeople(context, item.People || []);
 
-        populateListView($('#listStudios', context), (item.Studios || []).map(function (element) { return element.Name || ''; }));
+        populateListView($('#listStudios', context)[0], (item.Studios || []).map(function (element) { return element.Name || ''; }));
 
-        populateListView($('#listTags', context), item.Tags);
-        populateListView($('#listKeywords', context), item.Keywords);
+        populateListView($('#listTags', context)[0], item.Tags);
+        populateListView($('#listKeywords', context)[0], item.Keywords);
 
         var lockData = (item.LockData || false);
         var chkLockData = context.querySelector("#chkLockData");
         chkLockData.checked = lockData;
         if (chkLockData.checked) {
-            $('#providerSettingsContainer', context).hide();
+            $('.providerSettingsContainer', context).hide();
         } else {
-            $('#providerSettingsContainer', context).show();
+            $('.providerSettingsContainer', context).show();
         }
         populateInternetProviderSettings(context, item, item.LockedFields);
 
@@ -613,17 +1013,33 @@
     }
 
     function populateListView(list, items, sortCallback) {
-        //items = items || [];
-        //if (typeof (sortCallback) === 'undefined') {
-        //    items.sort(function (a, b) { return a.toLowerCase().localeCompare(b.toLowerCase()); });
-        //} else {
-        //    items = sortCallback(items);
-        //}
-        //var html = '';
-        //for (var i = 0; i < items.length; i++) {
-        //    html += '<li data-mini="true"><a class="data">' + items[i] + '</a><a href="#" onclick="EditItemMetadataPage.removeElementFromListview(this)" class="btnRemoveFromEditorList"></a></li>';
-        //}
-        //list.html(html).listview('refresh');
+
+        items = items || [];
+        if (typeof (sortCallback) === 'undefined') {
+            items.sort(function (a, b) { return a.toLowerCase().localeCompare(b.toLowerCase()); });
+        } else {
+            items = sortCallback(items);
+        }
+        var html = '';
+        for (var i = 0; i < items.length; i++) {
+            html += '<paper-icon-item>';
+
+            html += '<paper-fab mini style="background-color:#444;" icon="live-tv" item-icon></paper-fab>';
+
+            html += '<paper-item-body>';
+
+            html += '<div class="textValue">';
+            html += items[i];
+            html += '</div>';
+
+            html += '</paper-item-body>';
+
+            html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnRemoveFromEditorList"></paper-icon-button>';
+
+            html += '</paper-icon-item>';
+        }
+
+        list.innerHTML = html;
     }
 
     function populatePeople(context, people) {
@@ -631,34 +1047,36 @@
         var lastType = '';
         var html = '';
 
-        var elem = $('#peopleList', context);
+        var elem = context.querySelector('#peopleList');
 
         for (var i = 0, length = people.length; i < length; i++) {
 
             var person = people[i];
 
-            var type = person.Type || Globalize.translate('PersonTypePerson');
+            html += '<paper-icon-item>';
 
-            if (type != lastType) {
-                html += '<li data-role="list-divider">' + type + '</li>';
-                lastType = type;
-            }
+            html += '<paper-fab class="btnEditPerson" data-index="' + i + '" mini style="background-color:#444;" icon="person" item-icon></paper-fab>';
 
-            html += '<li><a class="btnEditPerson" href="#" data-index="' + i + '">';
+            html += '<paper-item-body>';
+            html += '<a class="btnEditPerson clearLink" href="#" data-index="' + i + '">';
 
-            html += '<h3>' + (person.Name || '') + '</h3>';
+            html += '<div class="textValue">';
+            html += (person.Name || '');
+            html += '</div>';
 
             if (person.Role && person.Role != lastType) {
-                html += '<p>' + (person.Role) + '</p>';
+                html += '<div secondary>' + (person.Role) + '</div>';
             }
+
             html += '</a>';
+            html += '</paper-item-body>';
 
-            html += '<a class="btnDeletePerson" href="#" data-icon="delete" data-index="' + i + '">' + Globalize.translate('Delete') + '</a>';
+            html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnDeletePerson"></paper-icon-button>';
 
-            html += '</li>';
+            html += '</paper-icon-item>';
         }
 
-        //elem.html(html).listview('refresh');
+        elem.innerHTML = html;
 
         $('.btnDeletePerson', elem).on('click', function () {
 
@@ -691,7 +1109,7 @@
     }
 
     function populateInternetProviderSettings(context, item, lockedFields) {
-        var container = $('#providerSettingsContainer', context);
+        var container = $('.providerSettingsContainer', context);
         lockedFields = lockedFields || new Array();
 
         var metadatafields = [
@@ -732,7 +1150,6 @@
 
     function reload(context, itemId) {
 
-        unbindItemChanged();
         Dashboard.showLoadingMsg();
 
         Promise.all([getItem(itemId), getEditorConfig(itemId)]).then(function (responses) {
@@ -776,7 +1193,6 @@
             }
 
             Dashboard.hideLoadingMsg();
-            bindItemChanged(context);
         });
     }
 
@@ -793,9 +1209,13 @@
 
                     var template = this.response;
                     var dlg = paperDialogHelper.createDialog({
-                        removeOnClose: true
+                        removeOnClose: true,
+                        size: 'medium'
                     });
 
+                    dlg.classList.add('ui-body-b');
+                    dlg.classList.add('background-theme-b');
+
                     dlg.classList.add('formDialog');
 
                     var html = '';
@@ -808,16 +1228,43 @@
                     paperDialogHelper.open(dlg);
 
                     dlg.addEventListener('iron-overlay-closed', function () {
+                        bindItemChanged(context);
                         resolve();
                     });
 
-                    currentDialog = dlg;
+                    currentContext = dlg;
 
                     init(dlg);
 
                     reload(dlg, itemId);
                 }
 
+                xhr.send();
+            });
+        },
+
+        embed: function (elem, itemId) {
+            return new Promise(function (resolve, reject) {
+
+                Dashboard.showLoadingMsg();
+
+                var xhr = new XMLHttpRequest();
+                xhr.open('GET', 'components/metadataeditor/metadataeditor.template.html', true);
+
+                xhr.onload = function (e) {
+
+                    var template = this.response;
+
+                    elem.innerHTML = Globalize.translateDocument(template);
+
+                    elem.querySelector('.btnCancel').classList.add('hide');
+
+                    currentContext = elem;
+
+                    init(elem);
+                    reload(elem, itemId);
+                }
+
                 xhr.send();
             });
         }
