@@ -1,4 +1,4 @@
-﻿(function (window, chrome, console) {
+﻿define([], function () {
 
     // Based on https://github.com/googlecast/CastVideos-chrome/blob/master/CastVideos.js
     var currentResolve;
@@ -90,6 +90,8 @@
      */
     CastPlayer.prototype.initializeCastPlayer = function () {
 
+        var chrome = window.chrome;
+
         if (!chrome) {
             return;
         }
@@ -861,9 +863,21 @@
 
         castPlayer = new CastPlayer();
 
-        MediaController.registerPlayer(new chromecastPlayer());
+        var registeredPlayer = new chromecastPlayer();
+        MediaController.registerPlayer(registeredPlayer);
+
+        // To allow the native android app to override
+        document.dispatchEvent(new CustomEvent("chromecastloaded", {
+            detail: {
+                player: registeredPlayer
+            }
+        }));
     }
 
-    requirejs(["https://www.gstatic.com/cv/js/sender/v1/cast_sender.js"], initializeChromecast);
+    var fileref = document.createElement('script');
+    fileref.setAttribute("type", "text/javascript");
+    fileref.onload = initializeChromecast;
+    fileref.setAttribute("src", "https://www.gstatic.com/cv/js/sender/v1/cast_sender.js");
+    document.querySelector('head').appendChild(fileref);
 
-})(window, window.chrome, console);
\ No newline at end of file
+});
\ No newline at end of file
