@@ -2,14 +2,7 @@
 
     function loadPage(page, config) {
 
-        $('#chkEnableDebugEncodingLogging', page).checked(config.EnableDebugLogging).checkboxradio('refresh');
-        $('#chkEnableThrottle', page).checked(config.EnableThrottling).checkboxradio('refresh');
-
-        $('.radioEncodingQuality', page).each(function () {
-
-            this.checked = config.EncodingQuality == this.value;
-
-        }).checkboxradio('refresh');
+        page.querySelector('#chkEnableThrottle').checked = config.EnableThrottling;
 
         $('#selectVideoDecoder', page).val(config.HardwareAccelerationType);
         $('#selectThreadCount', page).val(config.EncodingThreadCount);
@@ -20,22 +13,37 @@
     }
 
     function onSubmit() {
-        Dashboard.showLoadingMsg();
 
         var form = this;
 
-        ApiClient.getNamedConfiguration("encoding").then(function (config) {
+        var onDecoderConfirmed = function() {
+            Dashboard.showLoadingMsg();
 
-            config.EnableDebugLogging = $('#chkEnableDebugEncodingLogging', form).checked();
-            config.EncodingQuality = $('.radioEncodingQuality:checked', form).val();
-            config.DownMixAudioBoost = $('#txtDownMixAudioBoost', form).val();
-            config.TranscodingTempPath = $('#txtTranscodingTempPath', form).val();
-            config.EnableThrottling = $('#chkEnableThrottle', form).checked();
-            config.EncodingThreadCount = $('#selectThreadCount', form).val();
-            config.HardwareAccelerationType = $('#selectVideoDecoder', form).val();
+            ApiClient.getNamedConfiguration("encoding").then(function (config) {
+
+                config.DownMixAudioBoost = $('#txtDownMixAudioBoost', form).val();
+                config.TranscodingTempPath = $('#txtTranscodingTempPath', form).val();
+                config.EncodingThreadCount = $('#selectThreadCount', form).val();
+                config.HardwareAccelerationType = $('#selectVideoDecoder', form).val();
+
+                config.EnableThrottling = form.querySelector('#chkEnableThrottle').checked;
+
+                ApiClient.updateNamedConfiguration("encoding", config).then(Dashboard.processServerConfigurationUpdateResult);
+            });
+        };
+
+        if ($('#selectVideoDecoder', form).val()) {
+
+            Dashboard.alert({
+                callback: onDecoderConfirmed,
+                title: Globalize.translate('TitleHardwareAcceleration'),
+                message: Globalize.translate('HardwareAccelerationWarning')
+            });
+
+        } else {
+            onDecoderConfirmed();
+        }
 
-            ApiClient.updateNamedConfiguration("encoding", config).then(Dashboard.processServerConfigurationUpdateResult);
-        });
 
         // Disable default form submission
         return false;
