@@ -181,11 +181,13 @@
 
     function onPlayItemButtonClick() {
 
-        var id = this.getAttribute('data-itemid');
-        var type = this.getAttribute('data-itemtype');
-        var isFolder = this.getAttribute('data-isfolder') == 'true';
-        var mediaType = this.getAttribute('data-mediatype');
-        var resumePosition = parseInt(this.getAttribute('data-resumeposition'));
+        var target = this;
+
+        var id = target.getAttribute('data-itemid');
+        var type = target.getAttribute('data-itemtype');
+        var isFolder = target.getAttribute('data-isfolder') == 'true';
+        var mediaType = target.getAttribute('data-mediatype');
+        var resumePosition = parseInt(target.getAttribute('data-resumeposition'));
 
         LibraryBrowser.showPlayMenu(this, id, type, isFolder, mediaType, resumePosition);
 
@@ -450,9 +452,9 @@
                 }
             }
 
-            require(['actionsheet'], function () {
+            require(['actionsheet'], function (actionsheet) {
 
-                ActionSheetElement.show({
+                actionsheet.show({
                     items: items,
                     positionTo: displayContextItem,
                     callback: function (id) {
@@ -469,7 +471,7 @@
                                 PlaylistManager.showPanel([itemId]);
                                 break;
                             case 'delete':
-                                LibraryBrowser.deleteItem(itemId);
+                                LibraryBrowser.deleteItems([itemId]);
                                 break;
                             case 'download':
                                 {
@@ -788,7 +790,7 @@
             showOverlayTimeout = setTimeout(function () {
                 onShowTimerExpired(elem);
 
-            }, 1000);
+            }, 1200);
         }
 
         function preventTouchHover() {
@@ -852,11 +854,19 @@
 
         require(['hammer'], function (Hammer) {
 
-            var hammertime = new Hammer(element);
+            var manager = new Hammer.Manager(element);
+
+            var press = new Hammer.Press({
+                time: 500
+            });
+
+            manager.add(press);
+
+            //var hammertime = new Hammer(element);
             element.classList.add('hasTapHold');
 
-            hammertime.on('press', onTapHold);
-            hammertime.on('pressup', onTapHoldUp);
+            manager.on('press', onTapHold);
+            manager.on('pressup', onTapHoldUp);
         });
 
         showTapHoldHelp(element);
@@ -994,11 +1004,11 @@
 
             selectionCommandsPanel.innerHTML = html;
 
-            $('.btnCloseSelectionPanel', selectionCommandsPanel).on('click', hideSelections);
+            selectionCommandsPanel.querySelector('.btnCloseSelectionPanel').addEventListener('click', hideSelections);
 
             var btnSelectionPanelOptions = selectionCommandsPanel.querySelector('.btnSelectionPanelOptions');
 
-            $(btnSelectionPanelOptions).on('click', showMenuForSelectedItems);
+            btnSelectionPanelOptions.addEventListener('click', showMenuForSelectedItems);
 
             if (!browserInfo.mobile) {
                 shake(btnSelectionPanelOptions, 1);
@@ -1025,7 +1035,7 @@
 
     function showSelections(initialCard) {
 
-        require(['paper-checkbox'], function() {
+        require(['paper-checkbox'], function () {
             var cards = document.querySelectorAll('.card');
             for (var i = 0, length = cards.length; i < length; i++) {
                 showSelection(cards[i]);
@@ -1101,6 +1111,14 @@
                 ironIcon: 'playlist-add'
             });
 
+            if (user.Policy.EnableContentDeletion) {
+                items.push({
+                    name: Globalize.translate('ButtonDelete'),
+                    id: 'delete',
+                    ironIcon: 'delete'
+                });
+            }
+
             if (user.Policy.EnableContentDownloading && AppInfo.supportsDownloading) {
                 //items.push({
                 //    name: Globalize.translate('ButtonDownload'),
@@ -1127,9 +1145,9 @@
                 ironIcon: 'sync'
             });
 
-            require(['actionsheet'], function () {
+            require(['actionsheet'], function (actionsheet) {
 
-                ActionSheetElement.show({
+                actionsheet.show({
                     items: items,
                     positionTo: e.target,
                     callback: function (id) {
@@ -1149,6 +1167,12 @@
                                 PlaylistManager.showPanel(items);
                                 hideSelections();
                                 break;
+                            case 'delete':
+                                LibraryBrowser.deleteItems(items).then(function () {
+                                    Dashboard.navigate('index.html');
+                                });
+                                hideSelections();
+                                break;
                             case 'groupvideos':
                                 combineVersions($($.mobile.activePage)[0], items);
                                 break;
