@@ -50,7 +50,9 @@
 
         document.body.appendChild(viewMenuBar);
 
-        ImageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
+        require(['imageLoader'], function (imageLoader) {
+            imageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
+        });
 
         document.dispatchEvent(new CustomEvent("headercreated", {}));
         bindMenuEvents();
@@ -284,10 +286,8 @@
         if (userAtTop) {
 
             html += '<div class="drawerUserPanel">';
-            html += '<div class="drawerUserPanelInner">';
-            html += '<div class="drawerUserPanelContent">';
 
-            var imgWidth = 60;
+            var imgWidth = 40;
 
             if (hasUserImage) {
                 var url = user.imageUrl;
@@ -303,8 +303,6 @@
             html += user.name;
             html += '</div>';
 
-            html += '</div>';
-            html += '</div>';
             html += '</div>';
 
             html += '<a class="sidebarLink lnkMediaFolder" data-itemid="remote" href="index.html" onclick="return LibraryMenu.onLinkClicked(event, this);"><iron-icon icon="home" class="sidebarLinkIcon" style="color:#2196F3;"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonHome') + '</span></a>';
@@ -323,7 +321,10 @@
         var userHeader = drawer.querySelector('.userheader');
 
         userHeader.innerHTML = html;
-        ImageLoader.fillImages(userHeader.getElementsByClassName('lazy'));
+
+        require(['imageLoader'], function (imageLoader) {
+            imageLoader.fillImages(userHeader.getElementsByClassName('lazy'));
+        });
     }
 
     function refreshLibraryInfoInDrawer(user, drawer) {
@@ -545,7 +546,7 @@
     }
 
     function showUserAtTop() {
-        return Dashboard.isConnectMode() || browserInfo.mobile;
+        return AppInfo.isNativeApp;
     }
 
     var requiresLibraryMenuRefresh = false;
@@ -673,22 +674,24 @@
 
     function updateCastIcon() {
 
+        var context = document;
+
+        var btnCast = context.querySelector('.btnCast');
+
         var info = MediaController.getPlayerInfo();
 
         if (info.isLocalPlayer) {
 
-            $('.btnCast').removeClass('btnActiveCast').each(function () {
-                this.icon = 'cast';
-            });
-            $('.headerSelectedPlayer').html('');
+            btnCast.icon = 'cast';
+            btnCast.classList.remove('btnActiveCast');
+
+            context.querySelector('.headerSelectedPlayer').innerHTML = '';
 
         } else {
 
-            $('.btnCast').addClass('btnActiveCast').each(function () {
-                this.icon = 'cast-connected';
-            });
-
-            $('.headerSelectedPlayer').html((info.deviceName || info.name));
+            btnCast.icon = 'cast-connected';
+            btnCast.classList.add('btnActiveCast');
+            context.querySelector('.headerSelectedPlayer').innerHTML = info.deviceName || info.name;
         }
     }
 
@@ -791,6 +794,21 @@
         }
     }
 
+    pageClassOn('pageinit', 'page', function () {
+
+        var page = this;
+
+        var isLibraryPage = page.classList.contains('libraryPage');
+
+        if (isLibraryPage) {
+
+            var navs = page.querySelectorAll('.libraryViewNav');
+            for (var i = 0, length = navs.length; i < length; i++) {
+                initHeadRoom(navs[i]);
+            }
+        }
+    });
+
     pageClassOn('pagebeforeshow', 'page', function () {
 
         var page = this;
@@ -822,11 +840,6 @@
             document.body.classList.add('libraryDocument');
             document.body.classList.remove('dashboardDocument');
             document.body.classList.remove('hideMainDrawer');
-
-            var navs = page.querySelectorAll('.libraryViewNav');
-            for (var i = 0, length = navs.length; i < length; i++) {
-                initHeadRoom(navs[i]);
-            }
         }
         else if (page.classList.contains('type-interior')) {
 
@@ -840,21 +853,6 @@
             document.body.classList.remove('dashboardDocument');
             document.body.classList.add('hideMainDrawer');
         }
-
-        // Set drawer background color
-        var darkDrawer = false;
-        if (!Dashboard.isConnectMode() && !browserInfo.mobile) {
-            darkDrawer = true;
-        }
-
-        var drawer = document.querySelector('.mainDrawerPanel #drawer');
-        if (drawer) {
-            if (darkDrawer) {
-                drawer.classList.add('darkDrawer');
-            } else {
-                drawer.classList.remove('darkDrawer');
-            }
-        }
     });
 
     function updateTitle(page) {
@@ -934,6 +932,14 @@
         initializeApiClient(window.ApiClient);
     }
 
+    function setDrawerClass() {
+
+        var drawer = document.querySelector('.mainDrawerPanel #drawer');
+        if (drawer) {
+            drawer.classList.add('darkDrawer');
+        }
+    }
+
     var mainDrawerPanel = document.querySelector('.mainDrawerPanel');
     mainDrawerPanel.addEventListener('iron-select', onMainDrawerSelect);
 
@@ -946,6 +952,7 @@
     Events.on(ConnectionManager, 'localusersignedin', function (e, user) {
         requiresLibraryMenuRefresh = true;
         requiresDrawerRefresh = true;
+        setDrawerClass();
         ConnectionManager.user(ConnectionManager.getApiClient(user.ServerId)).then(updateUserInHeader);
     });
 
@@ -959,6 +966,8 @@
         updateCastIcon();
     });
 
+    setDrawerClass();
+
 })(window, document, jQuery, window.devicePixelRatio);
 
 (function () {
