@@ -70,7 +70,8 @@
             showParentTitle: true,
             centerText: true,
             coverImage: true,
-            lazy: true
+            lazy: true,
+            overlayPlayButton: true
 
         });
 
@@ -84,7 +85,8 @@
         ApiClient.getLiveTvRecordings({
 
             userId: Dashboard.getCurrentUserId(),
-            IsInProgress: true
+            IsInProgress: true,
+            Fields: 'CanDelete'
 
         }).then(function (result) {
 
@@ -96,7 +98,8 @@
 
             userId: Dashboard.getCurrentUserId(),
             limit: 12,
-            IsInProgress: false
+            IsInProgress: false,
+            Fields: 'CanDelete'
 
         }).then(function (result) {
 
