@@ -64,7 +64,7 @@
         });
     }
 
-    function showPlayerSelection(button) {
+    function showPlayerSelection(button, enableHistory) {
 
         var playerInfo = MediaController.getPlayerInfo();
 
@@ -93,14 +93,15 @@
 
             });
 
-            require(['actionsheet'], function () {
+            require(['actionsheet'], function (actionsheet) {
 
                 Dashboard.hideLoadingMsg();
 
-                ActionSheetElement.show({
+                actionsheet.show({
                     title: Globalize.translate('HeaderSelectPlayer'),
                     items: menuItems,
                     positionTo: button,
+                    enableHistory: enableHistory !== false,
                     callback: function (id) {
 
                         var target = targets.filter(function (t) {
@@ -413,9 +414,9 @@
                     id: 'cancel'
                 });
 
-                require(['actionsheet'], function () {
+                require(['actionsheet'], function (actionsheet) {
 
-                    ActionSheetElement.show({
+                    actionsheet.show({
                         items: menuItems,
                         //positionTo: positionTo,
                         title: Globalize.translate('ConfirmEndPlayerSession'),
@@ -1028,6 +1029,8 @@
     }
 
     MediaController.init = function () {
+
+        console.log('Beginning MediaController.init');
         if (window.ApiClient) {
             initializeApiClient(window.ApiClient);
         }
