@@ -72,18 +72,16 @@
         require(['prompt'], function (prompt) {
 
             prompt({
-                text: Globalize.translate('LabelNewName'),
-                title: Globalize.translate('HeaderRenameMediaFolder'),
-                callback: function (newName) {
+                label: Globalize.translate('LabelNewName')
 
-                    if (newName && newName != virtualFolder.Name) {
+            }).then(function (newName) {
+                if (newName && newName != virtualFolder.Name) {
 
-                        var refreshAfterChange = shouldRefreshLibraryAfterChanges(page);
+                    var refreshAfterChange = shouldRefreshLibraryAfterChanges(page);
 
-                        ApiClient.renameVirtualFolder(virtualFolder.Name, newName, refreshAfterChange).then(function () {
-                            reloadLibrary(page);
-                        });
-                    }
+                    ApiClient.renameVirtualFolder(virtualFolder.Name, newName, refreshAfterChange).then(function () {
+                        reloadLibrary(page);
+                    });
                 }
             });
 
@@ -122,9 +120,9 @@
             ironIcon: 'mode-edit'
         });
 
-        require(['actionsheet'], function () {
+        require(['actionsheet'], function (actionsheet) {
 
-            ActionSheetElement.show({
+            actionsheet.show({
                 items: menuItems,
                 positionTo: elem,
                 callback: function (resultId) {
@@ -314,7 +312,7 @@
         html += "</div>";
 
         if (!imgUrl && virtualFolder.showNameWithIcon) {
-            html += '<div class="cardImage iconCardImage addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;font-size:140%;cursor:pointer;">';
+            html += '<h1 class="cardImage iconCardImage addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;">';
 
             html += '<div>';
             html += '<iron-icon icon="' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '" style="width:45%;height:45%;color:#888;"></iron-icon>';
@@ -326,7 +324,7 @@
             }
             html += "</div>";
 
-            html += '</div>';
+            html += '</h1>';
         }
 
         html += '<div class="cardFooter">';
