@@ -121,10 +121,12 @@
                 return opt;
             });
 
-            require(['actionsheet'], function () {
+            require(['actionsheet'], function (actionsheet) {
 
-                ActionSheetElement.show({
+                actionsheet.show({
                     items: menuItems,
+                    // history.back() will cause the video player to stop
+                    enableHistory: false,
                     positionTo: $('.videoSubtitleButton')[0],
                     callback: function (id) {
 
@@ -140,7 +142,7 @@
 
         self.showQualityFlyout = function () {
 
-            require(['qualityoptions', 'actionsheet'], function (qualityoptions) {
+            require(['qualityoptions', 'actionsheet'], function (qualityoptions, actionsheet) {
 
                 var currentSrc = self.getCurrentSrc(self.currentMediaRenderer).toLowerCase();
                 var isStatic = currentSrc.indexOf('static=true') != -1;
@@ -174,8 +176,10 @@
                     return o.selected;
                 });
                 selectedId = selectedId.length ? selectedId[0].bitrate : null;
-                ActionSheetElement.show({
+                actionsheet.show({
                     items: menuItems,
+                    // history.back() will cause the video player to stop
+                    enableHistory: false,
                     positionTo: $('.videoQualityButton')[0],
                     callback: function (id) {
 
@@ -236,10 +240,12 @@
                 return opt;
             });
 
-            require(['actionsheet'], function () {
+            require(['actionsheet'], function (actionsheet) {
 
-                ActionSheetElement.show({
+                actionsheet.show({
                     items: menuItems,
+                    // history.back() will cause the video player to stop
+                    enableHistory: false,
                     positionTo: $('.videoAudioButton')[0],
                     callback: function (id) {
 
@@ -607,6 +613,7 @@
         self.onQualityOptionSelected = function (bitrate) {
 
             AppSettings.maxStreamingBitrate(bitrate);
+            AppSettings.enableAutomaticBitrateDetection(false);
 
             self.changeStream(self.getCurrentTicks(), {
                 Bitrate: bitrate
@@ -736,6 +743,7 @@
 
             html += '<paper-slider pin step="1" min="0" max="100" value="0" class="videoVolumeSlider" style="width:100px;vertical-align:middle;margin-left:-1em;margin-right:2em;display:inline-block;"></paper-slider>';
 
+            html += '<paper-icon-button icon="cast" class="mediaButton castButton" onclick="MediaController.showPlayerSelection(this, false);" style="width:32px;height:32px;"></paper-icon-button>';
             html += '<paper-icon-button icon="fullscreen" class="mediaButton fullscreenButton" onclick="MediaPlayer.toggleFullscreen();" id="video-fullscreenButton"></paper-icon-button>';
             html += '<paper-icon-button icon="info" class="mediaButton infoButton" onclick="MediaPlayer.toggleInfo();"></paper-icon-button>';
             //html += '<paper-icon-button icon="dvr" class="mediaButton guideButton" onclick="MediaPlayer.toggleGuide();"></paper-icon-button>';
@@ -967,9 +975,12 @@
 
                 self.createStreamInfo('Video', item, mediaSource, startPosition).then(function (streamInfo) {
 
+                    var isHls = streamInfo.url.toLowerCase().indexOf('.m3u8') != -1;
+
                     // Huge hack alert. Safari doesn't seem to like if the segments aren't available right away when playback starts
                     // This will start the transcoding process before actually feeding the video url into the player
-                    if (browserInfo.safari && !mediaSource.RunTimeTicks) {
+                    // Edit: Also seeing stalls from hls.js
+                    if ((browserInfo.safari || browserInfo.msie || browserInfo.firefox) && !mediaSource.RunTimeTicks && isHls) {
 
                         Dashboard.showLoadingMsg();
                         var hlsPlaylistUrl = streamInfo.url.replace('master.m3u8', 'live.m3u8');
@@ -1189,7 +1200,8 @@
         function onError() {
             var errorMsg = Globalize.translate('MessageErrorPlayingVideo');
 
-            if (item.Type == "TvChannel") {
+            var item = self.currentItem;
+            if (item && item.Type == "TvChannel") {
                 errorMsg += '<p>';
                 errorMsg += Globalize.translate('MessageEnsureOpenTuner');
                 errorMsg += '</p>';
@@ -1200,7 +1212,10 @@
                 message: errorMsg
             });
 
-            self.onPlaybackStopped.call(mediaRenderer);
+            var mediaRenderer = self.currentMediaRenderer;
+            if (mediaRenderer) {
+                self.onPlaybackStopped.call(mediaRenderer);
+            }
             self.nextTrack();
         }
 
