@@ -458,39 +458,27 @@ var Dashboard = {
     showLoadingMsg: function () {
 
         Dashboard.loadingVisible = true;
-        var elem = document.querySelector('.docspinner');
 
-        if (elem) {
-
-            // This is just an attempt to prevent the fade-in animation from running repeating and causing flickering
-            elem.active = true;
-            elem.classList.remove('hide');
-
-        } else if (!Dashboard.loadingAdded) {
-
-            Dashboard.loadingAdded = true;
-
-            require(['paper-spinner'], function () {
-                elem = document.createElement("paper-spinner");
-                elem.classList.add('docspinner');
-
-                document.body.appendChild(elem);
-                elem.active = Dashboard.loadingVisible == true;
-            });
-        }
+        require(['loading'], function (loading) {
+            if (Dashboard.loadingVisible) {
+                loading.show();
+            } else {
+                loading.hide();
+            }
+        });
     },
 
     hideLoadingMsg: function () {
 
         Dashboard.loadingVisible = false;
 
-        var elem = document.querySelector('.docspinner');
-
-        if (elem) {
-
-            elem.active = false;
-            elem.classList.add('hide');
-        }
+        require(['loading'], function (loading) {
+            if (Dashboard.loadingVisible) {
+                loading.show();
+            } else {
+                loading.hide();
+            }
+        });
     },
 
     getModalLoadingMsg: function () {
@@ -537,38 +525,24 @@ var Dashboard = {
 
         if (typeof options == "string") {
 
-            require(['paper-toast'], function () {
-                var message = options;
+            require(['toast'], function (toast) {
 
-                Dashboard.toastId = Dashboard.toastId || 0;
-
-                var id = 'toast' + (Dashboard.toastId++);
-
-                var elem = document.createElement("paper-toast");
-                elem.setAttribute('text', message);
-                elem.id = id;
-
-                document.body.appendChild(elem);
-
-                // This timeout is obviously messy but it's unclear how to determine when the webcomponent is ready for use
-                // element onload never fires
-                setTimeout(function () {
-                    elem.show();
-                }, 300);
-
-                setTimeout(function () {
-                    elem.parentNode.removeChild(elem);
-                }, 5300);
+                toast({
+                    text: options
+                });
 
             });
 
             return;
         }
 
-        // Cordova
-        if (navigator.notification && navigator.notification.alert && options.message.indexOf('<') == -1) {
+        if (browserInfo.mobile && options.message.indexOf('<') == -1) {
 
-            navigator.notification.alert(options.message, options.callback || function () { }, options.title || Globalize.translate('HeaderAlert'));
+            alert(options.message);
+
+            if (options.callback) {
+                options.callback();
+            }
 
         } else {
             require(['paper-dialog', 'fade-in-animation', 'fade-out-animation'], function () {
@@ -580,15 +554,13 @@ var Dashboard = {
     confirm: function (message, title, callback) {
 
         // Cordova
-        if (navigator.notification && navigator.notification.confirm && message.indexOf('<') == -1) {
+        if (browserInfo.mobile && message.indexOf('<') == -1) {
 
-            var buttonLabels = [Globalize.translate('ButtonOk'), Globalize.translate('ButtonCancel')];
+            var confirmed = confirm(message);
 
-            navigator.notification.confirm(message, function (index) {
-
-                callback(index == 1);
-
-            }, title || Globalize.translate('HeaderConfirm'), buttonLabels.join(','));
+            if (callback) {
+                callback(confirmed);
+            }
 
         } else {
 
@@ -703,36 +675,7 @@ var Dashboard = {
 
     showUserFlyout: function () {
 
-        require(['jqmpanel'], function () {
-            var html = '<div data-role="panel" data-position="right" data-display="overlay" id="userFlyout" data-position-fixed="true" data-theme="a">';
-
-            html += '<h3 class="userHeader">';
-
-            html += '</h3>';
-
-            html += '<form>';
-
-            html += '<p class="preferencesContainer"></p>';
-
-            html += '<p><button data-mini="true" type="button" onclick="Dashboard.logout();" data-icon="lock">' + Globalize.translate('ButtonSignOut') + '</button></p>';
-
-            html += '</form>';
-            html += '</div>';
-
-            $(document.body).append(html);
-
-            var userFlyout = document.querySelector('#userFlyout');
-            ImageLoader.lazyChildren(userFlyout);
-
-            $(userFlyout).panel({}).panel("open").on("panelclose", function () {
-
-                $(this).off("panelclose").remove();
-            });
-
-            ConnectionManager.user(window.ApiClient).then(function (user) {
-                Dashboard.updateUserFlyout(userFlyout, user);
-            });
-        });
+        Dashboard.navigate('mypreferencesmenu.html?userId=' + ApiClient.getCurrentUserId());
     },
 
     updateUserFlyout: function (elem, user) {
@@ -1584,7 +1527,6 @@ var AppInfo = {};
                 AppInfo.enableDetailPageChapters = false;
                 AppInfo.enableDetailsMenuImages = false;
                 AppInfo.enableMovieHomeSuggestions = false;
-                AppInfo.cardMargin = 'largeCardMargin';
 
                 AppInfo.forcedImageFormat = 'jpg';
             }
@@ -1630,9 +1572,6 @@ var AppInfo = {};
         AppInfo.supportsSyncPathSetting = isCordova && isAndroid;
         AppInfo.supportsUserDisplayLanguageSetting = Dashboard.isConnectMode() && !isCordova;
 
-        AppInfo.directPlayAudioContainers = [];
-        AppInfo.directPlayVideoContainers = [];
-
         if (isCordova && isIOS) {
             AppInfo.moreIcon = 'more-horiz';
         } else {
@@ -1642,7 +1581,15 @@ var AppInfo = {};
 
     function initializeApiClient(apiClient) {
 
-        apiClient.enableAppStorePolicy = AppInfo.enableAppStorePolicy;
+        if (AppInfo.enableAppStorePolicy) {
+            apiClient.getAvailablePlugins = function () {
+                return Promise.resolve([]);
+            };
+            apiClient.getInstalledPlugins = function () {
+                return Promise.resolve([]);
+            };
+        }
+
         apiClient.getDefaultImageQuality = Dashboard.getDefaultImageQuality;
         apiClient.normalizeImageOptions = Dashboard.normalizeImageOptions;
 
@@ -1680,6 +1627,7 @@ var AppInfo = {};
                 window.ConnectionManager.clearData();
             }
 
+            console.log('binding to apiclientcreated');
             Events.on(ConnectionManager, 'apiclientcreated', onApiClientCreated);
 
             if (Dashboard.isConnectMode()) {
@@ -1702,12 +1650,19 @@ var AppInfo = {};
                 }
 
             } else {
+
+                console.log('loading ApiClient singleton');
+
                 return getRequirePromise(['apiclient']).then(function (apiClientFactory) {
+
+                    console.log('creating ApiClient singleton');
+
                     var apiClient = new apiClientFactory(Dashboard.serverAddress(), AppInfo.appName, AppInfo.appVersion, AppInfo.deviceName, AppInfo.deviceId, window.devicePixelRatio);
                     apiClient.enableAutomaticNetworking = false;
                     ConnectionManager.addApiClient(apiClient);
                     Dashboard.importCss(apiClient.getUrl('Branding/Css'));
                     window.ApiClient = apiClient;
+                    console.log('loaded ApiClient singleton');
                 });
             }
         });
@@ -1754,10 +1709,6 @@ var AppInfo = {};
             elem.classList.add('touch');
         }
 
-        if (AppInfo.cardMargin) {
-            elem.classList.add(AppInfo.cardMargin);
-        }
-
         if (!AppInfo.enableStudioTabs) {
             elem.classList.add('studioTabDisabled');
         }
@@ -1806,18 +1757,29 @@ var AppInfo = {};
         }
     }
 
-    function initRequire() {
+    function returnFirstDependency(obj) {
+        return obj;
+    }
 
-        var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
+    function getBowerPath() {
 
         var bowerPath = "bower_components";
 
         // Put the version into the bower path since we can't easily put a query string param on html imports
         // Emby server will handle this
-        if (!Dashboard.isRunningInCordova()) {
+        if (Dashboard.isConnectMode() && !Dashboard.isRunningInCordova()) {
             bowerPath += window.dashboardVersion;
         }
 
+        return bowerPath;
+    }
+
+    function initRequire() {
+
+        var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
+
+        var bowerPath = getBowerPath();
+
         var apiClientBowerPath = bowerPath + "/emby-apiclient";
         var embyWebComponentsBowerPath = bowerPath + '/emby-webcomponents';
 
@@ -1842,26 +1804,45 @@ var AppInfo = {};
             credentialprovider: apiClientBowerPath + '/credentials',
             apiclient: apiClientBowerPath + '/apiclient',
             connectionmanagerfactory: apiClientBowerPath + '/connectionmanager',
+            visibleinviewport: embyWebComponentsBowerPath + "/visibleinviewport",
             browserdeviceprofile: embyWebComponentsBowerPath + "/browserdeviceprofile",
             browser: embyWebComponentsBowerPath + "/browser",
             qualityoptions: embyWebComponentsBowerPath + "/qualityoptions",
-            connectservice: apiClientBowerPath + '/connectservice'
+            connectservice: apiClientBowerPath + '/connectservice',
+            hammer: bowerPath + "/hammerjs/hammer.min",
+            performanceManager: embyWebComponentsBowerPath + "/performancemanager",
+            layoutManager: embyWebComponentsBowerPath + "/layoutmanager",
+            focusManager: embyWebComponentsBowerPath + "/focusmanager",
+            imageLoader: embyWebComponentsBowerPath + "/images/imagehelper"
         };
 
+        if (navigator.webkitPersistentStorage) {
+            paths.imageFetcher = embyWebComponentsBowerPath + "/images/persistentimagefetcher";
+        } else if (Dashboard.isRunningInCordova()) {
+            paths.imageFetcher = 'cordova/imagestore';
+        } else {
+            paths.imageFetcher = embyWebComponentsBowerPath + "/images/basicimagefetcher";
+        }
+
         paths.hlsjs = bowerPath + "/hls.js/dist/hls.min";
 
         if (Dashboard.isRunningInCordova()) {
-            paths.dialog = "cordova/dialog";
-            paths.prompt = "cordova/prompt";
             paths.sharingwidget = "cordova/sharingwidget";
             paths.serverdiscovery = "cordova/serverdiscovery";
             paths.wakeonlan = "cordova/wakeonlan";
+            paths.actionsheet = "cordova/actionsheet";
         } else {
-            paths.dialog = "components/dialog";
-            paths.prompt = "components/prompt";
             paths.sharingwidget = "components/sharingwidget";
             paths.serverdiscovery = apiClientBowerPath + "/serverdiscovery";
             paths.wakeonlan = apiClientBowerPath + "/wakeonlan";
+            paths.actionsheet = "scripts/actionsheet";
+        }
+
+        // hack for an android test before browserInfo is loaded
+        if (Dashboard.isRunningInCordova() && window.MainActivity) {
+            paths.appStorage = "cordova/android/appstorage";
+        } else {
+            paths.appStorage = apiClientBowerPath + "/appstorage";
         }
 
         var sha1Path = bowerPath + "/cryptojslib/components/sha1-min";
@@ -1877,6 +1858,7 @@ var AppInfo = {};
         };
 
         requirejs.config({
+            waitSeconds: 0,
             map: {
                 '*': {
                     'css': bowerPath + '/emby-webcomponents/requirecss',
@@ -1900,6 +1882,7 @@ var AppInfo = {};
         define("paper-slider", ["html!" + bowerPath + "/paper-slider/paper-slider.html"]);
         define("paper-tabs", ["html!" + bowerPath + "/paper-tabs/paper-tabs.html"]);
         define("paper-menu", ["html!" + bowerPath + "/paper-menu/paper-menu.html"]);
+        define("paper-material", ["html!" + bowerPath + "/paper-material/paper-material.html"]);
         define("paper-dialog", ["html!" + bowerPath + "/paper-dialog/paper-dialog.html"]);
         define("paper-dialog-scrollable", ["html!" + bowerPath + "/paper-dialog-scrollable/paper-dialog-scrollable.html"]);
         define("paper-button", ["html!" + bowerPath + "/paper-button/paper-button.html"]);
@@ -1926,32 +1909,33 @@ var AppInfo = {};
         define("paper-icon-item", ["html!" + bowerPath + "/paper-item/paper-icon-item.html"]);
         define("paper-item-body", ["html!" + bowerPath + "/paper-item/paper-item-body.html"]);
 
+        define("paper-collapse-item", ["html!" + bowerPath + "/paper-collapse-item/paper-collapse-item.html"]);
+
         define("jstree", [bowerPath + "/jstree/dist/jstree.min", "css!thirdparty/jstree/themes/default/style.min.css"]);
 
-        define("jqmicons", ['css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.icons.css']);
-        define("jqmtable", ["thirdparty/jquerymobile-1.4.5/jqm.table", 'css!thirdparty/jquerymobile-1.4.5/jqm.table.css']);
+        define('jqm', ['thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.js']);
+        define("jqmbase", ['css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.theme.css']);
+        define("jqmicons", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.icons.css']);
+        define("jqmtable", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.table", 'css!thirdparty/jquerymobile-1.4.5/jqm.table.css']);
 
-        define("jqmwidget", ["thirdparty/jquerymobile-1.4.5/jqm.widget"]);
+        define("jqmwidget", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.widget"]);
 
-        define("jqmslider", ["thirdparty/jquerymobile-1.4.5/jqm.slider", 'css!thirdparty/jquerymobile-1.4.5/jqm.slider.css']);
+        define("jqmslider", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.slider", 'css!thirdparty/jquerymobile-1.4.5/jqm.slider.css']);
 
-        define("jqmpopup", ["thirdparty/jquerymobile-1.4.5/jqm.popup", 'css!thirdparty/jquerymobile-1.4.5/jqm.popup.css']);
+        define("jqmpopup", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.popup", 'css!thirdparty/jquerymobile-1.4.5/jqm.popup.css']);
 
-        define("jqmlistview", ["thirdparty/jquerymobile-1.4.5/jqm.listview", 'css!thirdparty/jquerymobile-1.4.5/jqm.listview.css']);
+        define("jqmlistview", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jqm.listview.css']);
 
-        define("jqmcontrolgroup", ["thirdparty/jquerymobile-1.4.5/jqm.controlgroup", 'css!thirdparty/jquerymobile-1.4.5/jqm.controlgroup.css']);
+        define("jqmcontrolgroup", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jqm.controlgroup.css']);
 
-        define("jqmcollapsible", ["jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.collapsible", 'css!thirdparty/jquerymobile-1.4.5/jqm.collapsible.css']);
+        define("jqmcollapsible", ['jqmbase', "jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.collapsible", 'css!thirdparty/jquerymobile-1.4.5/jqm.collapsible.css']);
 
-        define("jqmcheckbox", ["jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.checkbox", 'css!thirdparty/jquerymobile-1.4.5/jqm.checkbox.css']);
+        define("jqmcheckbox", ['jqmbase', "jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.checkbox", 'css!thirdparty/jquerymobile-1.4.5/jqm.checkbox.css']);
 
-        define("jqmpanel", ["thirdparty/jquerymobile-1.4.5/jqm.panel", 'css!thirdparty/jquerymobile-1.4.5/jqm.panel.css']);
+        define("jqmpanel", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.panel", 'css!thirdparty/jquerymobile-1.4.5/jqm.panel.css']);
 
-        define("hammer", [bowerPath + "/hammerjs/hammer.min"], function (Hammer) {
-            return Hammer;
-        });
-
-        define("swipebox", [bowerPath + '/swipebox/src/js/jquery.swipebox.min', "css!" + bowerPath + "/swipebox/src/css/swipebox.min.css"]);
+        define("iron-icon-set", ["html!" + bowerPath + "/iron-icon/iron-icon.html", "html!" + bowerPath + "/iron-iconset-svg/iron-iconset-svg.html"]);
+        define("slideshow", [embyWebComponentsBowerPath + "/slideshow/slideshow"], returnFirstDependency);
 
         define('fetch', [bowerPath + '/fetch/fetch']);
         define('webcomponentsjs', [bowerPath + '/webcomponentsjs/webcomponents-lite.min.js']);
@@ -1971,8 +1955,6 @@ var AppInfo = {};
             define("localassetmanager", [apiClientBowerPath + "/localassetmanager"]);
             define("fileupload", [apiClientBowerPath + "/fileupload"]);
         }
-
-        define("apiclient-store", [apiClientBowerPath + "/store"]);
         define("apiclient-deferred", ["legacy/deferred"]);
         define("connectionmanager", [apiClientBowerPath + "/connectionmanager"]);
 
@@ -1981,24 +1963,81 @@ var AppInfo = {};
         define("multiserversync", [apiClientBowerPath + "/sync/multiserversync"]);
         define("offlineusersync", [apiClientBowerPath + "/sync/offlineusersync"]);
         define("mediasync", [apiClientBowerPath + "/sync/mediasync"]);
+
+        define("swiper", [bowerPath + "/Swiper/dist/js/swiper.min", "css!" + bowerPath + "/Swiper/dist/css/swiper.min"], returnFirstDependency);
+
+        define("paperdialoghelper", [embyWebComponentsBowerPath + "/paperdialoghelper/paperdialoghelper"], returnFirstDependency);
+        define("loading", [embyWebComponentsBowerPath + "/loading/loading"], returnFirstDependency);
+        define("toast", [embyWebComponentsBowerPath + "/toast/toast"], returnFirstDependency);
+
+        // alias
+        define("historyManager", [], function () {
+            return {
+                pushState: function (state, title, url) {
+                    state.navigate = false;
+                    history.pushState(state, title, url);
+                    jQuery.onStatePushed(state);
+                }
+            };
+        });
+
+        // mock this for now. not used in this app
+        define("inputManager", [], function () {
+            return {
+                on: function () {
+                },
+                off: function () {
+                }
+            };
+        });
+
+        define("connectionManager", [], function () {
+            return ConnectionManager;
+        });
+
+        define("globalize", [], function () {
+            return Globalize;
+        });
+
+        define('dialogText', [], getDialogText());
+    }
+
+    function getDialogText() {
+        return function () {
+            return {
+                buttonOk: 'ButtonOk',
+                buttonCancel: 'ButtonCancel'
+            };
+        };
+    }
+
+    function initRequireWithBrowser(browser) {
+
+        var bowerPath = getBowerPath();
+
+        var embyWebComponentsBowerPath = bowerPath + '/emby-webcomponents';
+
+        if (browser.mobile) {
+            define("prompt", [embyWebComponentsBowerPath + "/prompt/nativeprompt"], returnFirstDependency);
+        } else {
+            define("prompt", [embyWebComponentsBowerPath + "/prompt/prompt"], returnFirstDependency);
+        }
     }
 
     function init(hostingAppInfo) {
 
-        if (Dashboard.isRunningInCordova() && browserInfo.android) {
-            define("appstorage", ["cordova/android/appstorage"]);
-        } else {
-            define('appstorage', [], function () {
-                return appStorage;
-            });
-        }
-
         if (Dashboard.isRunningInCordova() && browserInfo.android) {
             define("nativedirectorychooser", ["cordova/android/nativedirectorychooser"]);
         }
 
         if (Dashboard.isRunningInCordova() && browserInfo.android) {
-            define("audiorenderer", ["cordova/android/vlcplayer"]);
+            if (MainActivity.getChromeVersion() >= 48) {
+                define("audiorenderer", ["scripts/htmlmediarenderer"]);
+                //define("audiorenderer", ["cordova/android/vlcplayer"]);
+            } else {
+                window.VlcAudio = true;
+                define("audiorenderer", ["cordova/android/vlcplayer"]);
+            }
             define("videorenderer", ["cordova/android/vlcplayer"]);
         }
         else if (Dashboard.isRunningInCordova() && browserInfo.safari) {
@@ -2027,12 +2066,6 @@ var AppInfo = {};
         });
         define("tileitemcss", ['css!css/tileitem.css']);
 
-        if (Dashboard.isRunningInCordova()) {
-            define("actionsheet", ["cordova/actionsheet"]);
-        } else {
-            define("actionsheet", ["scripts/actionsheet"]);
-        }
-
         define("sharingmanager", ["scripts/sharingmanager"]);
 
         if (Dashboard.isRunningInCordova() && browserInfo.safari) {
@@ -2053,8 +2086,6 @@ var AppInfo = {};
         deps.push('scripts/mediacontroller');
         deps.push('scripts/globalize');
 
-        deps.push('jQuery');
-
         deps.push('paper-drawer-panel');
 
         require(deps, function (events) {
@@ -2098,7 +2129,6 @@ var AppInfo = {};
         deps.push('connectionmanagerfactory');
         deps.push('credentialprovider');
 
-        deps.push('appstorage');
         deps.push('scripts/appsettings');
         deps.push('scripts/extensions');
 
@@ -2109,48 +2139,14 @@ var AppInfo = {};
                 MediaBrowser[i] = connectionManagerExports[i];
             }
 
-            // TODO: This needs to be deprecated, but it's used heavily
-            $.fn.checked = function (value) {
-                if (value === true || value === false) {
-                    // Set the value of the checkbox
-                    return $(this).each(function () {
-                        this.checked = value;
-                    });
-                } else {
-                    // Return check state
-                    return this.length && this[0].checked;
-                }
-            };
-
-            if (Dashboard.isRunningInCordova() && browserInfo.android) {
-                AppInfo.directPlayAudioContainers = "aac,mp3,mpa,wav,wma,mp2,ogg,oga,webma,ape,opus".split(',');
-
-                // TODO: This is going to exclude it from both playback and sync, so improve on this
-                if (AppSettings.syncLosslessAudio()) {
-                    AppInfo.directPlayAudioContainers.push('flac');
-                }
-
-                AppInfo.directPlayVideoContainers = "m4v,3gp,ts,mpegts,mov,xvid,vob,mkv,wmv,asf,ogm,ogv,m2v,avi,mpg,mpeg,mp4,webm".split(',');
-            }
-            else if (Dashboard.isRunningInCordova() && browserInfo.safari) {
-
-                AppInfo.directPlayAudioContainers = "aac,mp3,mpa,wav,wma,mp2,ogg,oga,webma,ape,opus".split(',');
-
-                // TODO: This is going to exclude it from both playback and sync, so improve on this
-                if (AppSettings.syncLosslessAudio()) {
-                    AppInfo.directPlayAudioContainers.push('flac');
-                }
-            }
-
             var promises = [];
             deps = [];
             deps.push('scripts/mediaplayer');
-            deps.push('thirdparty/jquery.unveil-custom.js');
             deps.push('emby-icons');
             deps.push('paper-icon-button');
             deps.push('paper-button');
-            deps.push('thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.js');
-            deps.push('scripts/librarybrowser');
+            deps.push('jQuery');
+
             promises.push(getRequirePromise(deps));
 
             promises.push(Globalize.ensure());
@@ -2158,6 +2154,7 @@ var AppInfo = {};
 
             Promise.all(promises).then(function () {
 
+                console.log('initAfterDependencies promises resolved');
                 MediaController.init();
 
                 document.title = Globalize.translateDocument(document.title, 'html');
@@ -2184,16 +2181,24 @@ var AppInfo = {};
                     depends = depends || [];
 
                     if (newHtml.indexOf('type-interior') != -1) {
-                        depends.push('jqmpopup');
-                        depends.push('jqmlistview');
-                        depends.push('jqmcollapsible');
-                        depends.push('jqmcontrolgroup');
-                        depends.push('jqmcheckbox');
-                        depends.push('scripts/notifications');
+                        addLegacyDependencies(depends, window.location.href);
                     }
 
                     require(depends, function () {
 
+                        // TODO: This needs to be deprecated, but it's used heavily
+                        $.fn.checked = function (value) {
+                            if (value === true || value === false) {
+                                // Set the value of the checkbox
+                                return $(this).each(function () {
+                                    this.checked = value;
+                                });
+                            } else {
+                                // Return check state
+                                return this.length && this[0].checked;
+                            }
+                        };
+
                         // Don't like having to use jQuery here, but it takes care of making sure that embedded script executes
                         $(mainDrawerPanelContent).html(Globalize.translateDocument(newHtml, 'html'));
                         onAppReady();
@@ -2208,8 +2213,12 @@ var AppInfo = {};
 
     function onAppReady() {
 
+        console.log('Begin onAppReady');
+
         var deps = [];
 
+        deps.push('imageLoader');
+
         if (!(AppInfo.isNativeApp && browserInfo.android)) {
             document.documentElement.classList.add('minimumSizeTabs');
         }
@@ -2250,10 +2259,15 @@ var AppInfo = {};
         deps.push('scripts/sync');
         deps.push('scripts/backdrops');
         deps.push('scripts/librarymenu');
+        deps.push('scripts/librarybrowser');
+        deps.push('jqm');
 
         deps.push('css!css/card.css');
 
-        require(deps, function () {
+        require(deps, function (imageLoader) {
+
+            imageLoader.enableFade = browserInfo.animate && !browserInfo.mobile;
+            window.ImageLoader = imageLoader;
 
             $.mobile.filterHtml = Dashboard.filterHtml;
 
@@ -2261,13 +2275,6 @@ var AppInfo = {};
 
             var postInitDependencies = [];
 
-            if (navigator.webkitPersistentStorage) {
-                postInitDependencies.push('components/imagestore');
-            }
-            else if (Dashboard.isRunningInCordova()) {
-                postInitDependencies.push('cordova/imagestore');
-            }
-
             postInitDependencies.push('scripts/thememediaplayer');
             postInitDependencies.push('scripts/remotecontrol');
             postInitDependencies.push('css!css/notifications.css');
@@ -2276,16 +2283,18 @@ var AppInfo = {};
 
             if (Dashboard.isRunningInCordova()) {
 
-                postInitDependencies.push('cordova/connectsdk');
-
                 if (browserInfo.android) {
                     postInitDependencies.push('cordova/android/mediasession');
+                    postInitDependencies.push('cordova/android/chromecast');
+
                 } else {
                     postInitDependencies.push('cordova/volume');
                 }
 
                 if (browserInfo.safari) {
 
+                    postInitDependencies.push('cordova/connectsdk/connectsdk');
+
                     postInitDependencies.push('cordova/ios/orientation');
 
                     if (Dashboard.capabilities().SupportsSync) {
@@ -2294,8 +2303,6 @@ var AppInfo = {};
                     }
                 }
 
-                //postInitDependencies.push('components/testermessage');
-
             } else if (browserInfo.chrome) {
                 postInitDependencies.push('scripts/chromecast');
             }
@@ -2328,11 +2335,14 @@ var AppInfo = {};
                     // Remove special characters
                     var cleanDeviceName = device.model.replace(/[^\w\s]/gi, '');
 
-                    var deviceId = window.MainActivity ? MainActivity.getLegacyDeviceId() : null;
-                    deviceId = deviceId || device.uuid;
+                    var deviceId = null;
+
+                    if (window.MainActivity) {
+                        deviceId = MainActivity.getLegacyDeviceId();
+                    }
 
                     resolve({
-                        deviceId: deviceId,
+                        deviceId: deviceId || device.uuid,
                         deviceName: cleanDeviceName,
                         appName: name,
                         appVersion: appVersion
@@ -2354,7 +2364,7 @@ var AppInfo = {};
                 deviceName = "Chrome";
             } else if (browserInfo.edge) {
                 deviceName = "Edge";
-            } else if (browserInfo.mozilla) {
+            } else if (browserInfo.firefox) {
                 deviceName = "Firefox";
             } else if (browserInfo.msie) {
                 deviceName = "Internet Explorer";
@@ -2384,7 +2394,8 @@ var AppInfo = {};
                 });
             }
 
-            var deviceId = appStorage.getItem('_deviceId');
+            var deviceIdKey = '_deviceId1';
+            var deviceId = appStorage.getItem(deviceIdKey);
 
             if (deviceId) {
                 onDeviceAdAcquired(deviceId);
@@ -2393,9 +2404,9 @@ var AppInfo = {};
                     var keys = [];
                     keys.push(navigator.userAgent);
                     keys.push((navigator.cpuClass || ""));
-
+                    keys.push(new Date().getTime());
                     var randomId = CryptoJS.SHA1(keys.join('|')).toString();
-                    appStorage.setItem('_deviceId', randomId);
+                    appStorage.setItem(deviceIdKey, randomId);
                     onDeviceAdAcquired(randomId);
                 });
             }
@@ -2418,15 +2429,19 @@ var AppInfo = {};
         var initialDependencies = [];
 
         initialDependencies.push('browser');
-        initialDependencies.push('apiclient-store');
+        initialDependencies.push('appStorage');
 
         if (!window.Promise) {
             initialDependencies.push('native-promise-only');
         }
 
-        require(initialDependencies, function (browser) {
+        require(initialDependencies, function (browser, appStorage) {
+
+            initRequireWithBrowser(browser);
 
             window.browserInfo = browser;
+            window.appStorage = appStorage;
+
             setAppInfo();
             setDocumentClasses();
 
@@ -2446,6 +2461,21 @@ var AppInfo = {};
 
 })();
 
+function addLegacyDependencies(depends, url) {
+
+    var isPluginpage = url.toLowerCase().indexOf('/configurationpage?') != -1;
+
+    if (isPluginpage) {
+        depends.push('jqmpopup');
+        depends.push('jqmcollapsible');
+        depends.push('jqmcheckbox');
+    }
+
+    depends.push('jqmcontrolgroup');
+    depends.push('jqmlistview');
+    depends.push('scripts/notifications');
+}
+
 function pageClassOn(eventName, className, fn) {
 
     document.addEventListener(eventName, function (e) {
@@ -2509,9 +2539,9 @@ pageClassOn('pageshow', "page", function () {
     }
 
     if (currentTheme != 'a' && !browserInfo.mobile) {
-        document.body.classList.add('darkScrollbars');
+        document.documentElement.classList.add('darkScrollbars');
     } else {
-        document.body.classList.remove('darkScrollbars');
+        document.documentElement.classList.remove('darkScrollbars');
     }
 
     Dashboard.ensurePageTitle(page);
