@@ -764,7 +764,9 @@
                 // a `popstate` on hash assignement or `replaceState` then we need avoid the branch
                 // that swallows the event created by the popstate generated by the hash assignment
                 // At the time of this writing this happens with Opera 12 and some version of IE
-                this.preventHashAssignPopState = false;
+                if (!browserInfo.safari) {
+                    this.preventHashAssignPopState = false;
+                }
 
                 state = $.extend({
                     url: href,
@@ -1194,12 +1196,7 @@
 
                     if (contentElem.classList.contains('type-interior')) {
                         dependencies = dependencies || [];
-                        dependencies.push('jqmpopup');
-                        dependencies.push('jqmlistview');
-                        dependencies.push('jqmcollapsible');
-                        dependencies.push('jqmcontrolgroup');
-                        dependencies.push('jqmcheckbox');
-                        dependencies.push('scripts/notifications');
+                        addLegacyDependencies(dependencies, absUrl);
                     }
 
                     require(dependencies, function () {
